@@ -198,4 +198,6 @@ BaremetalIntrospectionGroup = [
     cfg.StrOpt('auto_discovery_target_driver',
                help="The driver to set on the newly discovered nodes. "
                     "Only has effect with auto_discovery_feature is True."),
+    cfg.StrOpt('data_store',
+               help="The storage backend for storing introspection data."),
 ]
