@@ -10,10 +10,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
 import os
 import time
 
+from oslo_serialization import jsonutils as json
+
 import six
 import tempest
 from tempest import config
@@ -112,7 +113,7 @@ class InspectorScenarioTest(BaremetalScenarioTest):
         self.introspection_client.purge_rules()
 
     def rule_import(self, rule_path):
-        with open(rule_path, 'r') as fp:
+        with open(rule_path, 'rb') as fp:
             rules = json.load(fp)
         self.introspection_client.create_rules(rules)
 
